View source: R/run.SSM_unanimous_cpts.R
| run.SSM_unanimous_cpts | R Documentation |
SSM function This function is used to ...
run.SSM_unanimous_cpts(
data_ss,
formula_var,
ss_param_temp,
max_iteration = 100,
cpt_learning_param = list(cpt_method = "mean", burnin = 1/10, mergeband = 20,
convergence_cri = 10),
dlm_option = "smooth",
printFlag = T
)
data_ss |
contains all information, and only selected variables in formula_var enters the statespace model |
formula_var |
select variables from |
ss_param_temp |
a list of parameters to set up state-space model
|
max_iteration |
control for the convergence of changepoints, a positive integer |
cpt_learning_param |
a list of variable for change point learning
|
dlm_option |
using kalman filter or smoothing |
printFlag |
print data while processing |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.