View source: R/run.SSMimpute_unanimous_cpts.R
| run.SSMimpute_unanimous_cpts | R Documentation |
SSMimpute: state space model direct imputation on missing data in covariates
run.SSMimpute_unanimous_cpts(
data_ss_ori,
formula_var,
ss_param_temp,
initial_imputation_option = "StructTS",
estimate_convergence_cri = 0.01,
lik_convergence_cri = 0.01,
stepsize_for_newpart = 1/3,
max_iteration = 100,
cpt_learning_param = list(cpt_method = "mean", burnin = 1/10, mergeband = 20,
convergence_cri = 15),
cpt_initial_guess_option = "ignore",
dlm_option = "smooth",
m = 5,
seed = 1,
printFlag = T
)
data_ss_ori |
contains all information, and only selected variables in formula_var enters the statespace model |
formula_var |
select variables from <data_ss_ori> into the state space model |
ss_param_temp |
A list of parameters, details below |
initial_imputation_option |
for the first iteration of imputing missing y, choose StructTS or others, and can't be "ignore" |
estimate_convergence_cri |
critic value for convergence check, default 0.01 |
lik_convergence_cri |
critic value for convergence check, default 0.01 |
stepsize_for_newpart |
stepsize specified, default 1/3 |
max_iteration |
max iteration, default 100 |
cpt_learning_param |
<cpt_method> either "mean" or "meanvar" |
cpt_initial_guess_option |
option for initially learning cpts in preparation period |
dlm_option |
choose between smooth or filter |
m |
number of draws for multiple imputation |
seed |
random seed |
printFlag |
whether we need to print the Flag plots. |
<m0> initial values for states <C0>: initial values for variance of states <inits>: initial values for the estimating of all NA terms, via maximizing likelihood
A list
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.